@@ -2,24 +2,24 @@
 
 /* Pointer comparison macros
    Used for comparison of pointers that are not pointing
-   into the same array. It would be formally undefined to 
+   into the same array. It would be formally undefined to
    compare pointers directly according to standard C definition.
    This should get around it.
 
 */
 
-#define PTR_LT(a, b)	((Py_uintptr_t)(a) < (Py_uintptr_t)(b))
-#define PTR_EQ(a, b)	((Py_uintptr_t)(a) == (Py_uintptr_t)(b))
+#define PTR_LT(a, b)    ((Py_uintptr_t)(a) < (Py_uintptr_t)(b))
+#define PTR_EQ(a, b)    ((Py_uintptr_t)(a) == (Py_uintptr_t)(b))
 
-#define PTR_CMP(a,b)	(PTR_LT(a, b) ? -1 : (PTR_EQ(a, b) ? 0: 1))
+#define PTR_CMP(a,b)    (PTR_LT(a, b) ? -1 : (PTR_EQ(a, b) ? 0: 1))
 
 /* NodeGraphIter objects */
 
 typedef struct {
-	PyObject_HEAD
-	NyNodeGraphObject *nodegraph;
-	int i;
-	int oldsize;
+    PyObject_HEAD
+    NyNodeGraphObject *nodegraph;
+    Py_ssize_t i;
+    Py_ssize_t oldsize;
 } NyNodeGraphIterObject;
 
 /* NodeGraphIter methods */
@@ -27,16 +27,16 @@ typedef struct {
 static void
 ngiter_dealloc(NyNodeGraphIterObject *it)
 {
-	_PyObject_GC_UNTRACK(it);
-	Py_XDECREF(it->nodegraph);
-	PyObject_GC_Del(it);
+    PyObject_GC_UnTrack(it);
+    Py_XDECREF(it->nodegraph);
+    PyObject_GC_Del(it);
 }
 
 static int
 ngiter_traverse(NyNodeGraphIterObject *it, visitproc visit, void *arg)
 {
     if (!it->nodegraph)
-      return 0;
+        return 0;
     return visit((PyObject *)it->nodegraph, arg);
 }
 
@@ -46,15 +46,15 @@ ngiter_iternext(NyNodeGraphIterObject *ngi)
     PyObject *ret;
     NyNodeGraphEdge *e;
     if (ngi->i >= ngi->nodegraph->used_size)
-      return 0;
+        return 0;
     ret = PyTuple_New(2);
     if (!ret)
-      return 0;
+        return 0;
     if (ngi->nodegraph->used_size != ngi->oldsize ||
-	!ngi->nodegraph->is_sorted) {
-	Py_DECREF(ret);
-	PyErr_SetString(PyExc_RuntimeError, "nodegraph changed size during iteration");
-	return 0;
+        !ngi->nodegraph->is_sorted) {
+        Py_DECREF(ret);
+        PyErr_SetString(PyExc_RuntimeError, "nodegraph changed size during iteration");
+        return 0;
     }
     e = &ngi->nodegraph->edges[ngi->i];
     Py_INCREF(e->src);
@@ -68,42 +68,15 @@ ngiter_iternext(NyNodeGraphIterObject *ngi)
 /* NodeGraphIter type */
 
 PyTypeObject NyNodeGraphIter_Type = {
-	PyObject_HEAD_INIT(NULL)
-	0,					/* ob_size */
-	"nodegraph-iterator",			/* tp_name */
-	sizeof(NyNodeGraphIterObject),		/* tp_basicsize */
-	0,					/* tp_itemsize */
-	/* methods */
-	(destructor)ngiter_dealloc, 		/* tp_dealloc */
-	0,					/* tp_print */
-	0,					/* tp_getattr */
-	0,					/* tp_setattr */
-	0,					/* tp_compare */
-	0,					/* tp_repr */
-	0,					/* tp_as_number */
-	0,					/* tp_as_sequence */
-	0,					/* tp_as_mapping */
-	0,					/* tp_hash */
-	0,					/* tp_call */
-	0,					/* tp_str */
-	PyObject_GenericGetAttr,		/* tp_getattro */
-	0,					/* tp_setattro */
-	0,					/* tp_as_buffer */
-	Py_TPFLAGS_DEFAULT | Py_TPFLAGS_HAVE_GC,/* tp_flags */
- 	0,					/* tp_doc */
- 	(traverseproc)ngiter_traverse,		/* tp_traverse */
- 	0,					/* tp_clear */
-	0,					/* tp_richcompare */
-	0,					/* tp_weaklistoffset */
-	PyObject_SelfIter,			/* tp_iter */
-	(iternextfunc)ngiter_iternext,		/* tp_iternext */
-	0,					/* tp_methods */
-	0,					/* tp_members */
-	0,					/* tp_getset */
-	0,					/* tp_base */
-	0,					/* tp_dict */
-	0,					/* tp_descr_get */
-	0,					/* tp_descr_set */
+    PyVarObject_HEAD_INIT(NULL, 0)
+    .tp_name      = "nodegraph-iterator",
+    .tp_basicsize = sizeof(NyNodeGraphIterObject),
+    .tp_dealloc   = (destructor)ngiter_dealloc,
+    .tp_getattro  = PyObject_GenericGetAttr,
+    .tp_flags     = Py_TPFLAGS_DEFAULT | Py_TPFLAGS_HAVE_GC,
+    .tp_traverse  = (traverseproc)ngiter_traverse,
+    .tp_iter      = PyObject_SelfIter,
+    .tp_iternext  = (iternextfunc)ngiter_iternext,
 };
 
 /* NodeGraph methods */
@@ -111,14 +84,14 @@ PyTypeObject NyNodeGraphIter_Type = {
 void
 NyNodeGraph_Clear(NyNodeGraphObject *ng)
 {
-    int N = ng->used_size;
+    Py_ssize_t N = ng->used_size;
     NyNodeGraphEdge *edges = ng->edges;
-    int i;
+    Py_ssize_t i;
     ng->edges = 0;
     ng->used_size = ng->allo_size = 0;
     for (i = 0; i < N; i++) {
-	Py_DECREF(edges[i].src);
-	Py_DECREF(edges[i].tgt);
+        Py_DECREF(edges[i].src);
+        Py_DECREF(edges[i].tgt);
     }
     PyMem_FREE(edges);
 }
@@ -137,33 +110,33 @@ static void
 ng_dealloc(PyObject *v)
 {
     NyNodeGraphObject *ng = (void *)v;
-    int i;
+    Py_ssize_t i;
     Py_TRASHCAN_SAFE_BEGIN(v)
-    _PyObject_GC_UNTRACK(v);
+    PyObject_GC_UnTrack(v);
     ng_gc_clear(ng);
     for (i = 0; i < ng->used_size; i++) {
-	Py_DECREF(ng->edges[i].src);
-	Py_DECREF(ng->edges[i].tgt);
+        Py_DECREF(ng->edges[i].src);
+        Py_DECREF(ng->edges[i].tgt);
     }
     PyMem_FREE(ng->edges);
-    ng->ob_type->tp_free(v);
+    Py_TYPE(ng)->tp_free(v);
     Py_TRASHCAN_SAFE_END(v)
-      
+
 }
 
 static int
 ng_gc_traverse(NyNodeGraphObject *ng, visitproc visit, void *arg)
 {
-    int i;
+    Py_ssize_t i;
     int err = 0;
     for (i = 0; i < ng->used_size; i++) {
-	err = visit(ng->edges[i].src, arg) ;
-	if (err) return err;
-	err = visit(ng->edges[i].tgt, arg) ;
-	if (err) return err;
+        err = visit(ng->edges[i].src, arg) ;
+        if (err) return err;
+        err = visit(ng->edges[i].tgt, arg) ;
+        if (err) return err;
     }
     if (ng->_hiding_tag_)
-      err = visit(ng->_hiding_tag_, arg);
+        err = visit(ng->_hiding_tag_, arg);
     return err;
 }
 
@@ -171,24 +144,23 @@ int
 NyNodeGraph_AddEdge(NyNodeGraphObject *ng, PyObject *src, PyObject *tgt)
 {
     if (!ng->is_preserving_duplicates &&
-	ng->used_size &&
-	ng->edges[ng->used_size-1].src == src &&
-	ng->edges[ng->used_size-1].tgt == tgt)
-      return 0;
+        ng->used_size &&
+        ng->edges[ng->used_size-1].src == src &&
+        ng->edges[ng->used_size-1].tgt == tgt)
+        return 0;
 
-
-    assert(src->ob_refcnt < 0xa000000 && (Py_uintptr_t)src->ob_type > 0x1000);
-    assert(tgt->ob_refcnt < 0xa000000 && (Py_uintptr_t)tgt->ob_type > 0x1000);
+    assert(Py_REFCNT(src) < 0xa000000 && (Py_uintptr_t)Py_TYPE(src) > 0x1000);
+    assert(Py_REFCNT(tgt) < 0xa000000 && (Py_uintptr_t)Py_TYPE(tgt) > 0x1000);
 
     if (ng->used_size >= ng->allo_size) {
-	int allo = roundupsize(ng->used_size + 1);
-	PyMem_RESIZE(ng->edges, NyNodeGraphEdge, allo);
-	if (!ng->edges) {
-	    ng->used_size = ng->allo_size = 0;
-	    PyErr_NoMemory();
-	    return -1;
-	}
-	ng->allo_size = allo;
+        Py_ssize_t allo = roundupsize(ng->used_size + 1);
+        PyMem_RESIZE(ng->edges, NyNodeGraphEdge, allo);
+        if (!ng->edges) {
+            ng->used_size = ng->allo_size = 0;
+            PyErr_NoMemory();
+            return -1;
+        }
+        ng->allo_size = allo;
     }
     Py_INCREF(src);
     Py_INCREF(tgt);
@@ -204,7 +176,7 @@ ng_compare(const void *x, const void *y)
 {
     int c = PTR_CMP(((NyNodeGraphEdge *)x)->src, ((NyNodeGraphEdge *)y)->src);
     if (!c)
-      c = PTR_CMP(((NyNodeGraphEdge *)x)->tgt, ((NyNodeGraphEdge *)y)->tgt);
+        c = PTR_CMP(((NyNodeGraphEdge *)x)->tgt, ((NyNodeGraphEdge *)y)->tgt);
     return c;
 }
 
@@ -219,7 +191,7 @@ static void
 ng_sort(NyNodeGraphObject *ng)
 {
     qsort(ng->edges, ng->used_size, sizeof(NyNodeGraphEdge),
-	  ng->is_preserving_duplicates ? ng_compare_src_only : ng_compare);
+          ng->is_preserving_duplicates ? ng_compare_src_only : ng_compare);
 }
 
 static void
@@ -227,21 +199,21 @@ ng_remove_dups(NyNodeGraphObject *ng)
 {
     NyNodeGraphEdge *dst, *src, *hi;
     if (ng->used_size <= 1)
-      return;
+        return;
     hi = ng->edges + ng->used_size;
     dst = ng->edges + 1;
     src = ng->edges + 1;
     while( src < hi )  {
-	if (src[0].src == dst[-1].src && src[0].tgt == dst[-1].tgt) {
-	    Py_DECREF(src[0].src);
-	    Py_DECREF(src[0].tgt);
-	    src++;
-	} else {
-	    if (src != dst)
-	      dst[0] = src[0];
-	    dst++;
-	    src++;
-	}
+        if (src[0].src == dst[-1].src && src[0].tgt == dst[-1].tgt) {
+            Py_DECREF(src[0].src);
+            Py_DECREF(src[0].tgt);
+            src++;
+        } else {
+            if (src != dst)
+                dst[0] = src[0];
+            dst++;
+            src++;
+        }
     }
     ng->used_size = dst - ng->edges;
 }
@@ -258,7 +230,7 @@ ng_sortetc(NyNodeGraphObject *ng)
 {
     ng_sort(ng);
     if (!ng->is_preserving_duplicates)
-      ng_remove_dups(ng);
+        ng_remove_dups(ng);
     ng_trim(ng);
     ng->is_sorted = 1;
 }
@@ -267,7 +239,7 @@ static void
 ng_maybesortetc(NyNodeGraphObject *ng)
 {
     if (!ng->is_sorted)
-      ng_sortetc(ng);
+        ng_sortetc(ng);
 }
 
 static char ng_add_edge_doc[] =
@@ -281,9 +253,9 @@ ng_add_edge(NyNodeGraphObject *ng, PyObject *args)
 {
     PyObject *src, *tgt;
     if (!PyArg_ParseTuple(args, "OO:",  &src, &tgt))
-      return NULL;
+        return NULL;
     if (NyNodeGraph_AddEdge(ng, src, tgt) == -1)
-      return NULL;
+        return NULL;
     Py_INCREF(Py_None);
     return Py_None;
 }
@@ -303,7 +275,7 @@ static int
 ng_add_edges_n1_trav(PyObject *obj, AETravArg *ta)
 {
     if (NyNodeGraph_AddEdge(ta->ng, obj, ta->tgt) == -1)
-      return -1;
+        return -1;
     return 0;
 }
 
@@ -314,9 +286,9 @@ ng_add_edges_n1(NyNodeGraphObject *ng, PyObject *args)
     PyObject *it;
     ta.ng = ng;
     if (!PyArg_ParseTuple(args, "OO:",  &it, &ta.tgt))
-      return NULL;
+        return NULL;
     if (iterable_iterate(it, (visitproc)ng_add_edges_n1_trav, &ta) == -1)
-      return 0;
+        return 0;
     Py_INCREF(Py_None);
     return Py_None;
 }
@@ -331,15 +303,15 @@ PyObject *
 ng_as_flat_list(NyNodeGraphObject *ng, PyObject *arg)
 {
     PyObject *r = PyList_New(0);
-    int i;
+    Py_ssize_t i;
     if (!r)
-      return 0;
+        return 0;
     for (i = 0; i < ng->used_size; i++) {
-	if ((PyList_Append(r, ng->edges[i].src) == -1) ||
-	    (PyList_Append(r, ng->edges[i].tgt) == -1)) {
-	    Py_DECREF(r);
-	    return 0;
-	}
+        if ((PyList_Append(r, ng->edges[i].src) == -1) ||
+            (PyList_Append(r, ng->edges[i].tgt) == -1)) {
+            Py_DECREF(r);
+            return 0;
+        }
     }
     return r;
 }
@@ -362,7 +334,7 @@ NyNodeGraph_SubtypeNew(PyTypeObject *type)
 {
     NyNodeGraphObject *ng = (NyNodeGraphObject *)type->tp_alloc(type, 1);
     if (!ng)
-      return NULL;
+        return NULL;
     ng->_hiding_tag_ = 0;
     ng->allo_size = ng->used_size = 0;
     ng->is_sorted = 0;
@@ -375,10 +347,10 @@ NyNodeGraph_SubtypeNew(PyTypeObject *type)
 NyNodeGraphObject *
 NyNodeGraph_SiblingNew(NyNodeGraphObject *ng)
 {
-    NyNodeGraphObject *cp = NyNodeGraph_SubtypeNew(ng->ob_type);
+    NyNodeGraphObject *cp = NyNodeGraph_SubtypeNew(Py_TYPE(ng));
     PyObject *he;
     if (!cp)
-      return 0;
+        return 0;
     he = cp->_hiding_tag_;
     cp->_hiding_tag_ = ng->_hiding_tag_;
     Py_XINCREF(cp->_hiding_tag_);
@@ -392,10 +364,10 @@ NyNodeGraph_Copy(NyNodeGraphObject *ng)
 {
     NyNodeGraphObject *cp = NyNodeGraph_SiblingNew(ng);
     if (!cp)
-      return 0;
+        return 0;
     if (NyNodeGraph_Update(cp, (PyObject *)ng) == -1) {
-	Py_DECREF(cp);
-	return 0;
+        Py_DECREF(cp);
+        return 0;
     }
     return cp;
 }
@@ -422,11 +394,11 @@ ng_dc_trav(PyObject *obj, DCTravArg *ta)
 {
     NyNodeGraphEdge *lo, *hi;
     if (NyNodeGraph_Region(ta->ng, obj, &lo, &hi) == -1) {
-	return -1;
+        return -1;
     }
     if (lo == hi) {
-	ta->ret = 0;
-	return 1;
+        ta->ret = 0;
+        return 1;
     }
     return 0;
 }
@@ -445,7 +417,7 @@ ng_domain_covers(NyNodeGraphObject *ng, PyObject *X)
     ta.ng = ng;
     ta.ret = 1;
     if (iterable_iterate(X, (visitproc)ng_dc_trav, &ta) == -1) {
-	return 0;
+        return 0;
     }
     result = ta.ret? Py_True:Py_False;
     Py_INCREF(result);
@@ -462,11 +434,11 @@ ng_dr_trav(PyObject *obj, DRTravArg *ta)
 {
     NyNodeGraphEdge *lo, *hi, *cur;
     if (NyNodeGraph_Region(ta->ng, obj, &lo, &hi) == -1) {
-	return -1;
+        return -1;
     }
     for (cur = lo; cur < hi; cur++) {
-	if (NyNodeGraph_AddEdge(ta->ret, obj, cur->tgt) == -1)
-	  return -1;
+        if (NyNodeGraph_AddEdge(ta->ret, obj, cur->tgt) == -1)
+            return -1;
     }
     return 0;
 }
@@ -485,10 +457,10 @@ ng_domain_restricted(NyNodeGraphObject *ng, PyObject *X)
     ta.ng = ng;
     ta.ret = NyNodeGraph_SiblingNew(ng);
     if (!ta.ret)
-      return 0;
+        return 0;
     if (iterable_iterate(X, (visitproc)ng_dr_trav, &ta) == -1) {
-	Py_DECREF(ta.ret);
-	return 0;
+        Py_DECREF(ta.ret);
+        return 0;
     }
     return (PyObject *)ta.ret;
 }
@@ -503,14 +475,14 @@ static PyObject *
 ng_get_domain(NyNodeGraphObject *ng, void *closure)
 {
     NyNodeSetObject *ns = NyMutNodeSet_NewHiding(ng->_hiding_tag_);
-    int i;
+    Py_ssize_t i;
     if (!ns)
-      return 0;
+        return 0;
     for (i = 0; i < ng->used_size; i++) {
-	if (NyNodeSet_setobj(ns, ng->edges[i].src) == -1) {
-	    Py_DECREF(ns);
-	    return 0;
-	}
+        if (NyNodeSet_setobj(ns, ng->edges[i].src) == -1) {
+            Py_DECREF(ns);
+            return 0;
+        }
     }
     return (PyObject *)ns;
 }
@@ -524,14 +496,14 @@ static PyObject *
 ng_get_range(NyNodeGraphObject *ng, void *closure)
 {
     NyNodeSetObject *ns = NyMutNodeSet_NewHiding(ng->_hiding_tag_);
-    int i;
+    Py_ssize_t i;
     if (!ns)
-      return 0;
+        return 0;
     for (i = 0; i < ng->used_size; i++) {
-	if (NyNodeSet_setobj(ns, ng->edges[i].tgt) == -1) {
-	    Py_DECREF(ns);
-	    return 0;
-	}
+        if (NyNodeSet_setobj(ns, ng->edges[i].tgt) == -1) {
+            Py_DECREF(ns);
+            return 0;
+        }
     }
     return (PyObject *)ns;
 }
@@ -539,11 +511,11 @@ ng_get_range(NyNodeGraphObject *ng, void *closure)
 int
 NyNodeGraph_Invert(NyNodeGraphObject *ng) {
     NyNodeGraphEdge *edge = ng->edges;
-    int i;
+    Py_ssize_t i;
     for (i = 0; i < ng->used_size; i++, edge++) {
-	PyObject *t = edge->src;
-	edge->src = edge->tgt;
-	edge->tgt = t;
+        PyObject *t = edge->src;
+        edge->src = edge->tgt;
+        edge->tgt = t;
     }
     ng->is_sorted = 0;
     return 0;
@@ -558,7 +530,7 @@ static PyObject *
 ng_invert(NyNodeGraphObject *ng, void *notused)
 {
     if (NyNodeGraph_Invert(ng) == -1)
-      return 0;
+        return 0;
     Py_INCREF(Py_None);
     return Py_None;
 }
@@ -569,13 +541,13 @@ NyNodeGraph_Inverted(NyNodeGraphObject *ng)
     NyNodeGraphObject *ob;
     ob = NyNodeGraph_Copy(ng);
     if (!ob)
-      return 0;
+        return 0;
     if (NyNodeGraph_Invert(ob) == -1) {
-	Py_DECREF(ob);
-	return 0;
+        Py_DECREF(ob);
+        return 0;
     }
     return ob;
-    
+
 }
 
 static char ng_inverted_doc[] =
@@ -594,7 +566,7 @@ ng_iter(NyNodeGraphObject *v)
 {
     NyNodeGraphIterObject *iter = PyObject_GC_New(NyNodeGraphIterObject, &NyNodeGraphIter_Type);
     if (!v)
-      return 0;
+        return 0;
     iter->nodegraph = v;
     Py_INCREF(v);
     iter->i = 0;
@@ -606,34 +578,32 @@ ng_iter(NyNodeGraphObject *v)
 
 int
 NyNodeGraph_Region(NyNodeGraphObject *ng, PyObject *key,
-		   NyNodeGraphEdge **lop, NyNodeGraphEdge **hip)
+                   NyNodeGraphEdge **lop, NyNodeGraphEdge **hip)
 {
     NyNodeGraphEdge *lo, *hi, *cur;
     ng_maybesortetc(ng);
     lo = ng->edges;
     hi = ng->edges + ng->used_size;
     if (lo >=  hi) {
-	*lop = *hip = lo;
-	return 0;
+        *lop = *hip = lo;
+        return 0;
     }
     for (;;) {
-	cur = lo + (hi - lo) / 2;
-	if (cur->src == key) {
-	    for (lo = cur; lo > ng->edges && (lo-1)->src == key; lo--)
-	      ;
-	    for (hi = cur + 1; hi < ng->edges + ng->used_size && hi->src == key;
-		 hi++)
-	      ;
-	    *lop = lo;
-	    *hip = hi;
-	    return 0;
-	} else if (cur == lo) {
-	    *lop = *hip = lo;
-	    return 0;
-	} else if (PTR_LT(cur->src, key)) /* Make sure use same lt as in sort */
-	  lo = cur;
-	else
-	  hi = cur;
+        cur = lo + (hi - lo) / 2;
+        if (cur->src == key) {
+            for (lo = cur; lo > ng->edges && (lo-1)->src == key; lo--);
+            for (hi = cur + 1; hi < ng->edges + ng->used_size && hi->src == key;
+                hi++);
+            *lop = lo;
+            *hip = hi;
+            return 0;
+        } else if (cur == lo) {
+            *lop = *hip = lo;
+            return 0;
+        } else if (PTR_LT(cur->src, key)) /* Make sure use same lt as in sort */
+            lo = cur;
+        else
+            hi = cur;
     }
 }
 
@@ -647,11 +617,11 @@ ng_relimg_trav(PyObject *obj, RITravArg *ta)
 {
     NyNodeGraphEdge *lo, *hi, *cur;
     if (NyNodeGraph_Region(ta->ng, obj, &lo, &hi) == -1) {
-	return -1;
+        return -1;
     }
     for (cur = lo; cur < hi; cur++) {
-	if (NyNodeSet_setobj(ta->hs, cur->tgt) == -1)
-	  return -1;
+        if (NyNodeSet_setobj(ta->hs, cur->tgt) == -1)
+            return -1;
     }
     return 0;
 }
@@ -669,12 +639,12 @@ ng_relimg(NyNodeGraphObject *ng, PyObject *S)
     ta.ng = ng;
     ta.hs = NyMutNodeSet_NewHiding(ng->_hiding_tag_);
     if (!ta.hs)
-      return 0;
+        return 0;
     ng_maybesortetc(ng);
     if (iterable_iterate(S, (visitproc)ng_relimg_trav, &ta) == -1)
-      goto err;
+        goto err;
     return ta.hs;
-  err:
+err:
     Py_DECREF(ta.hs);
     return 0;
 }
@@ -683,13 +653,13 @@ static int
 ng_update_visit(PyObject *obj, NyNodeGraphObject *ng)
 {
     if (!PyTuple_Check(obj) || PyTuple_GET_SIZE(obj) != 2) {
-	PyErr_SetString(PyExc_TypeError, "update: right argument must be sequence of 2-tuples");
-	return -1;
+        PyErr_SetString(PyExc_TypeError, "update: right argument must be sequence of 2-tuples");
+        return -1;
     }
     if (NyNodeGraph_AddEdge(ng,
-			    PyTuple_GET_ITEM(obj, 0),
-			    PyTuple_GET_ITEM(obj, 1)) == -1)
-      return -1;
+                            PyTuple_GET_ITEM(obj, 0),
+                            PyTuple_GET_ITEM(obj, 1)) == -1)
+        return -1;
     return 0;
 }
 
@@ -712,7 +682,7 @@ static PyObject *
 ng_update(NyNodeGraphObject *ng, PyObject *arg)
 {
     if (NyNodeGraph_Update(ng, arg) == -1)
-      return 0;
+        return 0;
     Py_INCREF(Py_None);
     return Py_None;
 }
@@ -728,10 +698,10 @@ ng_updated(NyNodeGraphObject *ng, PyObject *arg)
 {
     ng = NyNodeGraph_Copy(ng);
     if (!ng)
-      return 0;
+        return 0;
     if (NyNodeGraph_Update(ng, arg) == -1) {
-	Py_DECREF(ng);
-	return 0;
+        Py_DECREF(ng);
+        return 0;
     }
     return (PyObject *)ng;
 }
@@ -751,15 +721,15 @@ static PyMethodDef ng_methods[] = {
     {"relimg", (PyCFunction)ng_relimg, METH_O, ng_relimg_doc},
     {"update", (PyCFunction)ng_update, METH_O, ng_update_doc},
     {"updated", (PyCFunction)ng_updated, METH_O, ng_updated_doc},
-    {NULL,		NULL}		/* sentinel */
+    {0} /* sentinel */
 };
 
-static int
+static size_t
 nodegraph_size(PyObject *obj) {
-    int z = obj->ob_type->tp_basicsize +
-      ((NyNodeGraphObject *)obj)->allo_size * sizeof(NyNodeGraphEdge);
+    Py_ssize_t z = Py_TYPE(obj)->tp_basicsize +
+        ((NyNodeGraphObject *)obj)->allo_size * sizeof(NyNodeGraphEdge);
     if (PyObject_IS_GC(obj))
-	z += sizeof(PyGC_Head);
+        z += sizeof(PyGC_Head);
     return z;
 }
 
@@ -768,7 +738,7 @@ nodegraph_traverse(NyHeapTraverse *t)
 {
     NyNodeGraphObject *ng = (void *)t->obj;
     if (t->_hiding_tag_ != ng->_hiding_tag_)
-      return ng->ob_type->tp_traverse((PyObject *)ng, t->visit, t->arg);
+        return Py_TYPE(ng)->tp_traverse((PyObject *)ng, t->visit, t->arg);
     return 0;
 }
 
@@ -776,25 +746,22 @@ static int
 nodegraph_relate(NyHeapRelate *r)
 {
     NyNodeGraphObject *ng = (void *)r->src;
-    int i;
-    char buf[100];
+    Py_ssize_t i;
     for (i = 0; i < ng->used_size; i++) {
-	if (r->tgt == ng->edges[i].src) {
-	    sprintf(buf, "edges[%d].src",i);
-	    if (r->visit(NYHR_INTERATTR, PyString_FromString(buf), r))
-	      return 0;
-	}
-	if (r->tgt == ng->edges[i].tgt) {
-	    sprintf(buf, "edges[%d].tgt",i);
-	    if (r->visit(NYHR_INTERATTR, PyString_FromString(buf), r))
-	      return 0;
-	}
+        if (r->tgt == ng->edges[i].src) {
+            if (r->visit(NYHR_INTERATTR, PyUnicode_FromFormat("edges[%d].src", i), r))
+                return 0;
+        }
+        if (r->tgt == ng->edges[i].tgt) {
+            if (r->visit(NYHR_INTERATTR, PyUnicode_FromFormat("edges[%d].tgt", i), r))
+                return 0;
+        }
     }
     return 0;
 }
 
 
-static char ng_doc[] = 
+static char ng_doc[] =
 "NodeGraph([iterable [,is_mapping]])\n\
 \n\
 Construct a new NodeGraph object. The arguments are:\n\
@@ -836,7 +803,7 @@ static PyGetSetDef ng_getset[] = {
 #define OFF(x) offsetof(NyNodeGraphObject, x)
 
 static PyMemberDef ng_members[] = {
-    {"_hiding_tag_",	 T_OBJECT_EX, OFF(_hiding_tag_), 0,
+    {"_hiding_tag_",     T_OBJECT_EX, OFF(_hiding_tag_), 0,
 "The hiding tag: if it is the the same object as the hiding tag\n\
 of a HeapView object, the nodegraph will be hidden from that view."},
     {"is_mapping", T_UBYTE, OFF(is_mapping), READONLY,
@@ -854,8 +821,7 @@ will need to be sorted to make it possible to find edges\n\
 automatically sort it if it was not already sorted.  The flag is\n\
 currently used from Python to see if the nodegraph has been used at\n\
 least once after update, so that it will not be cleared too early."},
-    {NULL} /* Sentinel */
-
+    {0} /* Sentinel */
 };
 
 #undef OFF
@@ -875,34 +841,34 @@ ng_subscript(NyNodeGraphObject *ng, PyObject *obj)
 {
     NyNodeGraphEdge *lo, *hi;
     PyObject *ret;
-    int i, size;
+    Py_ssize_t i, size;
     ng_maybesortetc(ng);
     if (NyNodeGraph_Region(ng, obj, &lo, &hi) == -1) {
-	return 0;
+        return 0;
     }
     size = hi - lo;
     if (ng->is_mapping) {
-	if (size == 0) {
-	    PyErr_SetObject(PyExc_KeyError, obj);
-	    return 0;
-	} else if (size > 1) {
-	    PyErr_SetString(PyExc_ValueError, "Ambiguos mapping");
-	    return 0;
-	}
-	ret = lo->tgt;
-	Py_INCREF(ret);
+        if (size == 0) {
+            PyErr_SetObject(PyExc_KeyError, obj);
+            return 0;
+        } else if (size > 1) {
+            PyErr_SetString(PyExc_ValueError, "Ambiguos mapping");
+            return 0;
+        }
+        ret = lo->tgt;
+        Py_INCREF(ret);
     } else {
-	ret = PyTuple_New(size);
-	if (!ret)
-	  return 0;
-	for (i = 0; i < size; i++, lo++) {
-	    Py_INCREF(lo->tgt);
-	    PyTuple_SET_ITEM(ret, i, lo->tgt);
-	}
+        ret = PyTuple_New(size);
+        if (!ret)
+            return 0;
+        for (i = 0; i < size; i++, lo++) {
+            Py_INCREF(lo->tgt);
+            PyTuple_SET_ITEM(ret, i, lo->tgt);
+        }
     }
 
     return ret;
-    
+
 
 }
 
@@ -911,47 +877,47 @@ static int
 ng_ass_sub(NyNodeGraphObject *ng, PyObject *v, PyObject *w)
 {
     NyNodeGraphEdge *lo, *hi;
-    int i, regsize, tupsize;
+    Py_ssize_t i, regsize, tupsize;
     if (!w) {
-	PyErr_SetString(PyExc_NotImplementedError,
-			"Item deletion is not implemented for nodegraphs.");
-	return -1;
+        PyErr_SetString(PyExc_NotImplementedError,
+                        "Item deletion is not implemented for nodegraphs.");
+        return -1;
     }
     ng_maybesortetc(ng);
     if (NyNodeGraph_Region(ng, v, &lo, &hi) == -1) {
-	return 0;
+        return 0;
     }
     regsize = hi - lo;
     if (ng->is_mapping) {
-	if (regsize != 1) {
-	    PyErr_SetString(PyExc_ValueError,
+        if (regsize != 1) {
+            PyErr_SetString(PyExc_ValueError,
 "ng_ass_sub: can not change number of edges (wants to always be fast);\n"
 "consider using .add_edge() etc. instead.");
-	    return -1;
-	} else {
-	    PyObject *old = lo->tgt;
-	    lo->tgt = w;
-	    Py_INCREF(w);
-	    Py_DECREF(old);
-	}
+            return -1;
+        } else {
+            PyObject *old = lo->tgt;
+            lo->tgt = w;
+            Py_INCREF(w);
+            Py_DECREF(old);
+        }
     } else {
-	if (!PyTuple_Check(w)) {
-	    PyErr_SetString(PyExc_TypeError, "ng_ass_sub: value to assign must be a tuple");
-	    return -1;
-	}
-	tupsize = PyTuple_GET_SIZE(w);
-	if (tupsize != regsize) {
-	    PyErr_SetString(PyExc_ValueError,
+        if (!PyTuple_Check(w)) {
+            PyErr_SetString(PyExc_TypeError, "ng_ass_sub: value to assign must be a tuple");
+            return -1;
+        }
+        tupsize = PyTuple_GET_SIZE(w);
+        if (tupsize != regsize) {
+            PyErr_SetString(PyExc_ValueError,
 "ng_ass_sub: can not change number of edges (wants to always be fast);\n"
 "consider using .add_edge() etc. instead.");
-	    return -1;
-	}
-	for (i = 0; i < regsize; i++) {
-	    PyObject *old = lo[i].tgt;
-	    lo[i].tgt = PyTuple_GET_ITEM(w, i);
-	    Py_INCREF(lo->tgt);
-	    Py_XDECREF(old);
-	}
+            return -1;
+        }
+        for (i = 0; i < regsize; i++) {
+            PyObject *old = lo[i].tgt;
+            lo[i].tgt = PyTuple_GET_ITEM(w, i);
+            Py_INCREF(lo->tgt);
+            Py_XDECREF(old);
+        }
     }
     return 0;
 }
@@ -959,9 +925,9 @@ ng_ass_sub(NyNodeGraphObject *ng, PyObject *v, PyObject *w)
 
 
 static PyMappingMethods ng_as_mapping = {
-    ng_length,		       /*mp_length*/
-    (binaryfunc)ng_subscript, /*mp_subscript*/
-    (objobjargproc)ng_ass_sub,/*mp_ass_subscript*/
+    .mp_length = ng_length,
+    .mp_subscript = (binaryfunc)ng_subscript,
+    .mp_ass_subscript = (objobjargproc)ng_ass_sub,
 };
 
 
@@ -973,68 +939,42 @@ ng_new(PyTypeObject *type, PyObject *args, PyObject *kwds)
     static char *kwlist[] = {"iterable", "is_mapping", 0};
     NyNodeGraphObject *ng;
     if (!PyArg_ParseTupleAndKeywords(args, kwds, "|OO:NodeGraph.__new__",
-				     kwlist,
-				     &iterable,
-				     &is_mapping))
-      return 0;
+                                     kwlist,
+                                     &iterable,
+                                     &is_mapping))
+        return 0;
     ng = NyNodeGraph_SubtypeNew(type);
     if (!ng)
-      return 0;
+        return 0;
     if (is_mapping && PyObject_IsTrue(is_mapping)) {
-	ng->is_mapping = 1;
+        ng->is_mapping = 1;
     }
     if (iterable && iterable != Py_None && NyNodeGraph_Update(ng, iterable) == -1) {
-	Py_DECREF(ng);
-	return 0;
+        Py_DECREF(ng);
+        return 0;
     }
     return (PyObject *)ng;
 }
 
 
 PyTypeObject NyNodeGraph_Type = {
-	PyObject_HEAD_INIT(NULL)
-	0,					/* ob_size */
-	"guppy.heapy.heapyc.NodeGraph",		/* tp_name */
-	sizeof(NyNodeGraphObject),		/* tp_basicsize */
-	0,					/* tp_itemsize */
-	/* methods */
-	(destructor)ng_dealloc, 		/* tp_dealloc */
-	0,					/* tp_print */
-	0,					/* tp_getattr */
-	0,					/* tp_setattr */
-	0,					/* tp_compare */
-	0,					/* tp_repr */
-	0,					/* tp_as_number */
-	0,					/* tp_as_sequence */
-	&ng_as_mapping,				/* tp_as_mapping */
-	0,					/* tp_hash */
-	0,					/* tp_call */
-	0,					/* tp_str */
-	PyObject_GenericGetAttr,		/* tp_getattro */
-	0,					/* tp_setattro */
-	0,					/* tp_as_buffer */
-	Py_TPFLAGS_DEFAULT | Py_TPFLAGS_HAVE_GC |
-	  	Py_TPFLAGS_BASETYPE,		/* tp_flags */
- 	ng_doc,					/* tp_doc */
- 	(traverseproc)ng_gc_traverse,		/* tp_traverse */
- 	(inquiry)ng_gc_clear,			/* tp_clear */
-	0,					/* tp_richcompare */
-	0,					/* tp_weaklistoffset */
-	(getiterfunc)ng_iter,			/* tp_iter */
-	0,					/* tp_iternext */
-	ng_methods,				/* tp_methods */
-	ng_members,				/* tp_members */
-	ng_getset,				/* tp_getset */
-	0,					/* tp_base */
-	0,					/* tp_dict */
-	0,					/* tp_descr_get */
-	0,					/* tp_descr_set */
-	0,					/* tp_dictoffset */
-	0,					/* tp_init */
-	PyType_GenericAlloc,			/* tp_alloc */
-	ng_new,					/* tp_new */
-	_PyObject_GC_Del,			/* tp_free */
-
+    PyVarObject_HEAD_INIT(NULL, 0)
+    .tp_name       = "guppy.heapy.heapyc.NodeGraph",
+    .tp_basicsize  = sizeof(NyNodeGraphObject),
+    .tp_dealloc    = (destructor)ng_dealloc,
+    .tp_as_mapping = &ng_as_mapping,
+    .tp_getattro   = PyObject_GenericGetAttr,
+    .tp_flags      = Py_TPFLAGS_DEFAULT | Py_TPFLAGS_HAVE_GC | Py_TPFLAGS_BASETYPE,
+    .tp_doc        = ng_doc,
+    .tp_traverse   = (traverseproc)ng_gc_traverse,
+    .tp_clear      = (inquiry)ng_gc_clear,
+    .tp_iter       = (getiterfunc)ng_iter,
+    .tp_methods    = ng_methods,
+    .tp_members    = ng_members,
+    .tp_getset     = ng_getset,
+    .tp_alloc      = PyType_GenericAlloc,
+    .tp_new        = ng_new,
+    .tp_free       = PyObject_GC_Del,
 };
 
 NyNodeGraphObject *
